@@ -37,6 +37,12 @@ private slots:
     void testVirtualMethods();
     void testDefaultValues();
     void testModifiedDefaultValues();
+    void testInnerClassOfAPolymorphicOne();
+    void testClassDefaultConstructors();
+    void testClassInheritedDefaultConstructors();
+    void testAbstractClassDefaultConstructors();
+    void testObjectTypesMustNotHaveCopyConstructors();
+    void testIsPolymorphic();
 };
 
 #endif // TESTABSTRACTMETACLASS_H
