@@ -45,6 +45,7 @@ Handler::Handler(TypeDatabase* database, bool generate)
     m_ignoreDepth = 0;
 
     tagNames["rejection"] = StackElement::Rejection;
+    tagNames["custom-type"] = StackElement::CustomTypeEntry;
     tagNames["primitive-type"] = StackElement::PrimitiveTypeEntry;
     tagNames["container-type"] = StackElement::ContainerTypeEntry;
     tagNames["object-type"] = StackElement::ObjectTypeEntry;
@@ -224,6 +225,14 @@ bool Handler::endElement(const QString &, const QString &localName, const QStrin
     case StackElement::TemplateInstanceEnum:
         switch (m_current->parent->type) {
         case StackElement::InjectCode:
+            if (m_current->parent->parent->type == StackElement::Root) {
+                CodeSnipList snips = m_current->parent->entry->codeSnips();
+                CodeSnip snip = snips.takeLast();
+                snip.addTemplateInstance(m_current->value.templateInstance);
+                snips.append(snip);
+                m_current->parent->entry->setCodeSnips(snips);
+                break;
+            }
         case StackElement::NativeToTarget:
         case StackElement::AddConversion:
             m_contextStack.top()->codeSnips.last().addTemplateInstance(m_current->value.templateInstance);
@@ -428,6 +437,21 @@ static QString getNamePrefix(StackElement* element)
     return names.join(".");
 }
 
+// Returns empty string if there's no error.
+static QString checkSignatureError(const QString& signature, const QString& tag)
+{
+    QString funcName = signature.left(signature.indexOf('(')).trimmed();
+    static QRegExp whiteSpace("\\s");
+    if (!funcName.startsWith("operator ") && funcName.contains(whiteSpace)) {
+        return QString("Error in <%1> tag signature attribute '%2'.\n"
+                       "White spaces aren't allowed in function names, "
+                       "and return types should not be part of the signature.")
+                  .arg(tag)
+                  .arg(signature);
+    }
+    return QString();
+}
+
 bool Handler::startElement(const QString &, const QString &n,
                            const QString &, const QXmlAttributes &atts)
 {
@@ -554,6 +578,11 @@ bool Handler::startElement(const QString &, const QString &n,
         if (element->type == StackElement::FunctionTypeEntry) {
             QString signature = attributes["signature"];
             name = signature.left(signature.indexOf('(')).trimmed();
+            QString errorString = checkSignatureError(signature, "function");
+            if (!errorString.isEmpty()) {
+                m_error = errorString;
+                return false;
+            }
             QString rename = attributes["rename"];
             if (!rename.isEmpty()) {
                 static QRegExp functionNameRegExp("^[a-zA-Z_][a-zA-Z0-9_]*$");
@@ -601,6 +630,9 @@ bool Handler::startElement(const QString &, const QString &n,
         }
 
         switch (element->type) {
+        case StackElement::CustomTypeEntry:
+            element->entry = new TypeEntry(name, TypeEntry::CustomType, since);
+            break;
         case StackElement::PrimitiveTypeEntry: {
             QString targetLangName = attributes["target-lang-name"];
             QString targetLangApiName = attributes["target-lang-api-name"];
@@ -1449,6 +1481,12 @@ bool Handler::startElement(const QString &, const QString &n,
                 return false;
             }
 
+            QString errorString = checkSignatureError(signature, "add-function");
+            if (!errorString.isEmpty()) {
+                m_error = errorString;
+                return false;
+            }
+
             AddedFunction func(signature, attributes["return-type"], since);
             func.setStatic(attributes["static"] == "yes");
             if (!signature.contains("("))
@@ -1488,6 +1526,12 @@ bool Handler::startElement(const QString &, const QString &n,
                 return false;
             }
 
+            QString errorString = checkSignatureError(signature, "modify-function");
+            if (!errorString.isEmpty()) {
+                m_error = errorString;
+                return false;
+            }
+
             FunctionModification mod(since);
             m_currentSignature = mod.signature = signature;
 
